/**
 *  qdswap.h by Tyler Montbriand, 2004
 *  Free software as in free beer.  Do whatever you want with it..
 */

#ifndef __QDSWAP_H__
#define __QDSWAP_H__
 /**
  * Hyperfast inline-assembly endian conversions are nice when you need 
  * them, but they don't work at compile-time.
  *
  * Trying to define endian's with SDL's byteswap operators fails 
  * whenever it tries to do anything fancy, but this one is guaranteed 
  * to work at compile-time.
  *
  * This means that you can do things like endian definitions that are
  * consistent under all byteorders:
  *  enum crossplatform_enum
  *  {
  *    E_0=myswap_be32(0)
  *  , E_1=myswap_be32(1)
  *  , E_2=myswap_be32(2)
  *  };
  * These need no translation when sent across a network to a machine of
  * opposite byte-order.
  */

#include <SDL/SDL_byteorder.h>

#define myswap32(x) (((x)>>24) | (((x)&0x00ff0000)>>8) | (((x)&0x0000ff00)<<8) | ((x)<<24))
#define myswap16(x) ( ((x)>>8) | ((x)<<8) )

#if SDL_BYTEORDER == SDL_BIG_ENDIAN
#  define myswap_be16(x) (x)
#  define myswap_le16(x) myswap16(x)
#  define myswap_be32(x) (x)
#  define myswap_le32(x) myswap32(x)
#else
#  define myswap_be16(x) myswap16(x)
#  define myswap_le16(x) (x)
#  define myswap_be32(x) myswap32(x)
#  define myswap_le32(x) (x)
#endif

#endif/*__QDSWAP_H__*/
